@@ -64,15 +64,19 @@ def arg_parser():
             exit(1)
         temp_dir = tempfile.mkdtemp()
         # version_dir_to_upload= os.path.join(upload_file_path, version_name)
-        zipped_file_path = os.path.join(temp_dir, version_name + '.zip')
-
+        # zipped_file_path = os.path.join(temp_dir, version_name + '.zip')
+        zipped_file_path = temp_dir
         # print('version_dir_to_upload: ', version_dir_to_upload)
         print('zipped_file_path: ', zipped_file_path)
+        print('temp_dir: ', temp_dir)
 
         # zipped_file_path:  /tmp/tmpwn5_qolh/2.5.zip
         # version_name:  2.5
         # upload_file_path:  /home/robin/Downloads/2.5
-        create_zip.create_zip(upload_file_path, zipped_file_path, version_name)
+
+        dir_to_zip = upload_file_path
+
+        create_zip.create_zip(dir_to_zip, zipped_file_path, version_name)
         push_software.push_software(zipped_file_path, radarType, version_name)
         remove_zip.remove_zip(zipped_file_path)
         exit(0)
